{% set is_210 = h.ckan_version().split('.')[1] | int >= 9 %}

<li class="item {{ activity.activity_type|replace(' ', '-')|lower }}">
    {% if is_210 %}
        <span class="fa-stack fa-lg">
            <i class="fa fa-circle fa-stack-2x icon"></i>
            <i class="fa fa-users fa-stack-1x fa-inverse"></i>
        </span>
    {% else %}
        <i class="fa icon fa-users"></i>
    {% endif %}

    {% if not is_210 %}
        <p>
    {% endif %}
    {{ _('{actor} updated the group {group}').format(
        actor=ah.actor(activity),
        group=ah.group(activity)
    )|safe }}
    <br />
    <span class="date" title="{{ h.render_datetime(activity.timestamp, with_hours=True) }}">
        {{ h.time_ago_from_timestamp(activity.timestamp) }}

        {% if can_show_activity_detail %}
	    &nbsp;|&nbsp;
            <a href="{{ h.url_for('toolbelt_group_changes.changes', id=activity.id) }}">
                {{ _('Changes') }}
            </a>
        {% endif %}
    </span>
    {% if not is_210 %}
        </p>
    {% endif %}
</li>
